/*******************************************************************************
* File Name: Acc_Enable.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Acc_Enable.h"


/*******************************************************************************
* Function Name: Acc_Enable_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Acc_Enable_Write(uint8 value) 
{
    uint8 staticBits = Acc_Enable_DR & ~Acc_Enable_MASK;
    Acc_Enable_DR = staticBits | ((value << Acc_Enable_SHIFT) & Acc_Enable_MASK);
}


/*******************************************************************************
* Function Name: Acc_Enable_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Acc_Enable_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Acc_Enable_0, mode);
}


/*******************************************************************************
* Function Name: Acc_Enable_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Acc_Enable_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Acc_Enable_Read(void) 
{
    return (Acc_Enable_PS & Acc_Enable_MASK) >> Acc_Enable_SHIFT;
}


/*******************************************************************************
* Function Name: Acc_Enable_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Acc_Enable_ReadDataReg(void) 
{
    return (Acc_Enable_DR & Acc_Enable_MASK) >> Acc_Enable_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Acc_Enable_INTSTAT) 

    /*******************************************************************************
    * Function Name: Acc_Enable_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Acc_Enable_ClearInterrupt(void) 
    {
        return (Acc_Enable_INTSTAT & Acc_Enable_MASK) >> Acc_Enable_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
