/*******************************************************************************
* File Name: St_Mot.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "St_Mot.h"


/*******************************************************************************
* Function Name: St_Mot_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void St_Mot_Write(uint8 value) 
{
    uint8 staticBits = St_Mot_DR & ~St_Mot_MASK;
    St_Mot_DR = staticBits | ((value << St_Mot_SHIFT) & St_Mot_MASK);
}


/*******************************************************************************
* Function Name: St_Mot_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void St_Mot_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(St_Mot_0, mode);
}


/*******************************************************************************
* Function Name: St_Mot_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro St_Mot_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 St_Mot_Read(void) 
{
    return (St_Mot_PS & St_Mot_MASK) >> St_Mot_SHIFT;
}


/*******************************************************************************
* Function Name: St_Mot_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 St_Mot_ReadDataReg(void) 
{
    return (St_Mot_DR & St_Mot_MASK) >> St_Mot_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(St_Mot_INTSTAT) 

    /*******************************************************************************
    * Function Name: St_Mot_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 St_Mot_ClearInterrupt(void) 
    {
        return (St_Mot_INTSTAT & St_Mot_MASK) >> St_Mot_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
